<template>
  <div class="info-location">
    <div class="header">
      <div class="title">
        <span class="name">{{ title }}</span>
      </div>
    </div>
    <div class="content">
      <div class="info">
        <div class="detail">
          <span class="label">联系地址：</span>
          <span class="value">{{ address }}</span>
        </div>
      </div>
    </div>
    <div class="search-around">
      <van-button hairline plain type="info" size="small" @click="searchAround">周边搜索</van-button>
    </div>
  </div>
</template>

<script>
import { Button } from "vant";

export default {
  name: "infoLocation",
  components: {
    [Button.name]: Button,
  },
  props: {
    data: Object,
  },
  computed: {
    title() {
      return `${this.data?.name}`;
    },
    address() {
      return this.data?.address || "";
    },
  },
  methods: {
    searchAround() {
      const coordinates = this.data.location.split(",");
      const data = { ...this.data, longitude: Number(coordinates[0]), latitude: Number(coordinates[1]), from: "location" };
      this.$emit("searchAround", data);
    },
  },
};
</script>

<style scoped lang="less">
.info-location {
  .header {
    width: 100%;
    height: 52px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    .title {
      display: flex;
      align-items: center;
      .name {
        font-size: 14px;
        font-family: PingFang SC-Medium, PingFang SC;
        font-weight: 500;
        color: #303133;
        line-height: 22px;
        margin-left: 8px;
      }
    }
  }
  .content {
    width: 100%;
    .info {
      width: 100%;
      padding: 12px 20px;
      .return {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC;
        font-weight: 400;
        color: #0f71ff;
        line-height: 22px;
        margin-bottom: 10px;
      }
      .detail {
        width: 100%;
        display: flex;
        align-items: center;
        margin-bottom: 10px;
        &:last-child {
          margin-bottom: 0;
        }
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
        }

        .value {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #303133;
          &-link {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            text-decoration: underline;
          }
        }
        .visible {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #0f71ff;
          margin-left: 2px;
        }
      }
    }
  }
  .search-around {
    width: 100%;
    height: 50px;
    display: flex;
    align-items: center;
    justify-content: center;
  }
}
</style>
